# RawElements


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**elements** | [**[RawElement]**](RawElement.md) |  | 
**units** | [**[RawUnit], none_type**](RawUnit.md) |  | [optional] 
**definitions** | [**[RawDefinition], none_type**](RawDefinition.md) |  | [optional] 
**property_sets** | [**[RawPropertySet], none_type**](RawPropertySet.md) |  | [optional] 
**classifications** | [**[RawClassification], none_type**](RawClassification.md) |  | [optional] 
**layers** | [**[RawLayer], none_type**](RawLayer.md) |  | [optional] 
**systems** | [**[RawSystem], none_type**](RawSystem.md) |  | [optional] 
**materials** | **bool, date, datetime, dict, float, int, list, str, none_type** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


